#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  The Plone Quickinstaller Script
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" Adds an Actionicon for GSXML
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 39020 $"

import logging
import string
from cStringIO import StringIO
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.DirectoryView import addDirectoryViews

from Products.gsxml.config import PROJECTNAME, SKINS_DIR, GLOBALS

LOGGER="gsxml.install"

def info(msg):
    logging.getLogger(LOGGER).info(msg)

def debug(msg):
    logging.getLogger(LOGGER).debug(msg)

def error(msg):
    logging.getLogger(LOGGER).error(msg)


def setupSkin(self, out):
    """ Setup product skin layer """
    skinstool=getToolByName(self, 'portal_skins')
    addDirectoryViews(skinstool, SKINS_DIR, GLOBALS)
    for skin in skinstool.getSkinSelections():
        path = skinstool.getSkinPath(skin)
        path = map(string.strip, string.split(path,','))
        if not PROJECTNAME in path:
            try:
                path.insert( path.index('custom')+1, PROJECTNAME)
            except ValueError:
                path.append(PROJECTNAME)
            path = string.join(path, ', ')
            skinstool.addSkinSelection(skin, path)
            out.write( 'setupSkin(): %s layer sucessfully installed into skin %s.\n' % (PROJECTNAME, skin))
            info( 'setupSkin(): %s layer sucessfully installed into skin %s' % (PROJECTNAME, skin) )
        else:
            out.write( 'setupSkin(): %s layer was already installed into skin %s.\n' % (PROJECTNAME, skin))
            info( "setupSkin(): %s layer was already installed into skin %s" % (PROJECTNAME, skin) )


def removeSkin(self, out, skins=[PROJECTNAME,]):
    """ Setup product skin layer """
    if skins:
        skinstool = getToolByName(self, 'portal_skins')
        for skinName in skinstool.getSkinSelections():
            path = skinstool.getSkinPath(skinName)
            path = [i.strip() for i in  path.split(',')]
            for s in skins:
                if s in path:
                    path.remove(s)
                s += '/'
                for layer in path:
                    if layer.startswith(s):
                        path.remove(layer)
            path = ','.join(path)
            skinstool.addSkinSelection(skinName, path)

            out.write( 'removeSkin(): successfully removed skin %s\n' % (skinName) )
            info( 'removeSkin(): successfully removed skin %s' % (skinName) )



def installGSXMLAction(self, out):
    """ Install the GSXML Action """
    actionsTool = getToolByName(self, 'portal_actions', None)
    if actionsTool is not None:
        for action in actionsTool.listActions():
            if action.getId() == 'gsxml_view':
                out.write("The 'gsxml_view' view already exists!\n")
                info("The 'gsxml_view' view already exists!")
                break # We already have the action
        else:
            actionsTool.addAction('gsxml_view',
                name='GSXML Tool',
                action='string:$object_url/gsxml',
                #XXX: condition missing
                #condition='python:portal.portal_interface.objectImplements( object, "Products.gsxml.interfaces.IXMLExportableContent" )',
                condition='',
                permission='Modify portal content',
                category='document_actions',
                visible=1,
                )
            out.write("Added 'gsxml_view' action to actions tool...\n")
            info("Added 'gsxml_view' action to actions tool...")


    iconsTool = getToolByName(self, 'portal_actionicons', None)
    if iconsTool is not None:
        for icon in iconsTool.listActionIcons():
            if icon.getActionId() == 'gsxml_view':
                out.write("The 'gsxml_view' icon already exists!\n")
                info("The 'gsxml_view' icon already exists!")
                break # We already have the icon
        else:
            iconsTool.addActionIcon(
                category='plone',
                action_id='gsxml_view',
                icon_expr='gsxml.png',
                title='GSXML Tool',
                )
            out.write("Added 'gsxml_view' icon to actionicons tool...\n")
            info("Added 'gsxml_view' icon to actionicons tool...")


def uninstallGSXMLAction(self, out):
    """ remove GSXML  action for content types """
    #remove action
    actionsTool = getToolByName(self, 'portal_actions', None)
    if actionsTool is not None:
        actions = actionsTool._cloneActions()
        actions = [a for a in actions if a.id != 'gsxml_view']
        actionsTool._actions = tuple(actions)

        out.write("Removed 'gsxml_view' action...\n")
        info("Removed 'gsxml_view' action...")

    #remove icon
    iconsTool = getToolByName(self, 'portal_actionicons', None)
    if iconsTool is not None:
        icons = iconsTool.listActionIcons()
        for i in icons:
            if i.getActionId() == "gsxml_view":
                iconsTool.removeActionIcon(i.getCategory(), i.getActionId())
                out.write("Removed ActionIcon %s from Category %s...\n" % ( i.getCategory(), i.getActionId() ) )
                info("Removed ActionIcon %s from Category %s..." % (  i.getActionId(), i.getCategory() ) )


def install(self):
    """ Product installation """
    out = StringIO()
    out.write('Installing GSXML... \n')
    setupSkin(self, out)
    installGSXMLAction(self, out)

    return out.getvalue()

def uninstall(self):
    """ Product uninstallation """
    out = StringIO()
    out.write('Removing GSXML... \n')
    removeSkin(self, out)
    uninstallGSXMLAction(self, out)

    return out.getvalue()

# vim: set ft=python ts=4 sw=4 expandtab :
