#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  Export Browser view
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" Provide a GUI for the GSXML Export step
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 39026 $"


import os
import logging
from zope.formlib import form
from Products.Five.formlib import formbase
from Products.Five.browser import pagetemplatefile

# import gsxml stuff
from Products.gsxml.interfaces import IGmailConfig, IFSConfig
from Products.gsxml.context import GmailExportContext, SimpleFSExportContext
from Products.gsxml.content import XMLContentFSExporter

TEMPLATE_PATH=os.path.abspath( os.path.join( os.path.dirname(__file__), "..", "templates" ) )
FORM_TEMPLATE=os.path.join( TEMPLATE_PATH, "gsxml_form.pt" )

LOGGER="gsxml.exportview"

def info(msg):
    logging.getLogger(LOGGER).info(msg)

def debug(msg):
    logging.getLogger(LOGGER).debug(msg)

def error(msg):
    logging.getLogger(LOGGER).error(msg)


class GmailForm(formbase.PageForm):
    form_fields = form.FormFields(IGmailConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "InQuant GSXML Gmail Export"

    @form.action("export")
    def action_export(self, action, data):
        info( "action_export_gmail: %s" % ( data ) )
        ex = XMLContentFSExporter( self.context )
        ec = GmailExportContext(data["username"], data["password"], exportid=data["exportid"])
        ex.export(ec, "structure", False)

class FSForm(formbase.PageForm):
    form_fields = form.FormFields(IFSConfig)
    template = pagetemplatefile.ZopeTwoPageTemplateFile( FORM_TEMPLATE )
    label = "InQuant GSXML Filesystem Export"

    @form.action("export")
    def action_export(self, action, data):
        info( "action_export_fs: %s" % ( data ) )
        ex = XMLContentFSExporter( self.context )
        ec = SimpleFSExportContext( data["path"] )
        ex.export(ec, "structure", False)

# vim: set ft=python ts=4 sw=4 expandtab :
