# libgmail research project
#
# Testing the API
#
# Copyright (c) 2006-2007 InQuant GmbH

""" Goal of this research is to find out whether the libgmail library
is useful for the gsxml project. The use case will be a simple way to
store, label, find and retrieve XML data which came from gsxml.
"""

__author__ = """Ramon Bartl <ramon_bartl@yahoo.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: $"

import libgmail
from getpass import getpass

# log into the account and get a account object to work from
def g_login():
    name = raw_input("Gmail account name: ")
    pw = getpass("Password: ")
    ga = libgmail.GmailAccount(name, pw)
    print "\nPlease wait, logging in..."

    try:
        ga.login()
    except libgmail.GmailLoginFailure:
        print "\nLogin failed. (Wrong username/password?)"
        return None
    else:
        print "Log in successful.\n"
        return ga

# get all files which are stored under the label 'gsxml'
def g_list(ga):
    filenames = {}
    r = ga.getMessagesByLabel('gsxml')
    for th in r:
        for m in th:
            for a in m.attachments:
                filenames[a.filename] = a
    return filenames

def g_query(ga, query):
    filenames = {}
    r = ga.getMessagesByQuery( query )
    for th in r:
        for m in th:
            for a in m.attachments:
                filenames[a.filename] = a
    return filenames

def g_msgquery(ga, query):
    messages = []
    result = ga.getMessagesByQuery( query )
    for th in result:
        for m in th:
            messages.append(m)
    return messages

# send a simple message with attachment
# GmailComposedMessage: __init__(self, to, subject, body, cc=None, bcc=None, filenames=None, files=None)
def g_send(ga):
    to = "ramon.bartl@googlemail.com"
    subject = "[GSXML]"
    msg = "GSXML Message"
    filenames = raw_input("Filename: ")

    gmsg = libgmail.GmailComposedMessage(to, subject, msg, None, None, [filenames])

    if ga.sendMessage(gmsg):
        print "Message sent `%s` successfully." % subject
    else:
        print "Could not send message."

