#  -*- coding: utf-8 -*-
#
#  GSXML - A Content Import/Export Product
#
#  Test Adapter registrations
#
#  Copyright (c) 2006-2007 InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""Integration tests for adapter registrations.

These tests ensure that the various adapter registrations are in effect,
not the exact functionality they promise. They utilise the full PloneTestCase
bases, since we are actually testing that the registrations are properly loaded
at Zope start-up, not just that they could be made to work (e.g. using the
zope testing API)
"""

__author__ = """Ramon Bartl <ramonski@ramonski.de>"""
__docformat__ = 'restructuredtext'
__revision__ = "$Revision: 38837 $"

import unittest
from Testing.ZopeTestCase import ZopeDocTestSuite

from base import GSXMLTestCase
from utils import optionflags

def test_marshaller_adapter():
    """ With the Marshaller we are able to transform content
        to XML and vice versa


    Import our interfaces::

        >>> from Products.ATContentTypes.content.base import ATCTContent
        >>> from Products.ATContentTypes.content.base import ATCTMixin
        >>> from Products.gsxml.interfaces import IXMLExportableContent
        >>> from Products.gsxml.interfaces import IXMLMarshaller
        >>> from Products.gsxml.interfaces import IXMLDemarshaller

    ATCT and ATMixin provide our marker interface IXMLExportableContent::

        >>> IXMLExportableContent.implementedBy( ATCTContent )
        True

        >>> IXMLExportableContent.implementedBy( ATCTMixin )
        True

    Some content we can work from::

        >>> self.setRoles(('Manager'),)
        >>> self.folder.invokeFactory('Document', 'doc')
        'doc'
        >>> doc = self.folder.doc

        >>> self.folder.invokeFactory('Folder', 'folder')
        'folder'
        >>> folder = self.folder.folder

        >>> self.folder.invokeFactory('Event', 'event')
        'event'
        >>> event = self.folder.event

        >>> self.folder.invokeFactory('Topic', 'news')
        'news'
        >>> news = self.folder.news

    Let's see if our content provides our markerinterface::

        >>> IXMLExportableContent.providedBy( doc )
        True

        >>> IXMLExportableContent.providedBy( folder )
        True

        >>> IXMLExportableContent.providedBy( event )
        True

        >>> IXMLExportableContent.providedBy( news )
        True

    do we have a marshallers and demarshallers for our content::

        >>> IXMLMarshaller(doc)
        <Products.gsxml.content.ATCTXMLMarshaller object at ...>

        >>> IXMLDemarshaller(doc)
        <Products.gsxml.content.ATCTXMLDemarshaller object at ...>

        >>> IXMLMarshaller(folder)
        <Products.gsxml.content.ATCTXMLMarshaller object at ...>

        >>> IXMLDemarshaller(folder)
        <Products.gsxml.content.ATCTXMLDemarshaller object at ...>

        >>> IXMLMarshaller(event)
        <Products.gsxml.content.ATCTXMLMarshaller object at ...>

        >>> IXMLDemarshaller(event)
        <Products.gsxml.content.ATCTXMLDemarshaller object at ...>

        >>> IXMLMarshaller(news)
        <Products.gsxml.content.ATCTXMLMarshaller object at ...>

        >>> IXMLDemarshaller(news)
        <Products.gsxml.content.ATCTXMLDemarshaller object at ...>
    """


def test_gsfs_adapter():
    """ we can import/export xml content by providing GenericSetup's
        IFilesystemExporter and IFilesystemImporter


    Import our interfaces::

        >>> from Products.GenericSetup.interfaces import IFilesystemExporter
        >>> from Products.GenericSetup.interfaces import IFilesystemImporter
        >>> from Products.gsxml.interfaces import IGSXMLFilesystemExporter
        >>> from Products.gsxml.interfaces import IGSXMLFilesystemImporter

    Some content we can work from::

        >>> self.setRoles(('Manager'),)
        >>> self.folder.invokeFactory('Document', 'doc')
        'doc'
        >>> doc = self.folder.doc

        >>> self.folder.invokeFactory('Folder', 'folder')
        'folder'
        >>> folder = self.folder.folder

        >>> self.folder.invokeFactory('Event', 'event')
        'event'
        >>> event = self.folder.event

        >>> self.folder.invokeFactory('Topic', 'news')
        'news'
        >>> news = self.folder.news

    does this content provide our importer and exporter::

        >>> IGSXMLFilesystemExporter(doc)
        <Products.gsxml.content.XMLContentFSExporter object at ...>

        >>> IGSXMLFilesystemImporter(doc)
        <Products.gsxml.content.XMLContentFSImporter object at ...>

        >>> IGSXMLFilesystemExporter(folder)
        <Products.gsxml.content.XMLContentFSExporter object at ...>

        >>> IGSXMLFilesystemImporter(folder)
        <Products.gsxml.content.XMLContentFSImporter object at ...>

        >>> IGSXMLFilesystemExporter(event)
        <Products.gsxml.content.XMLContentFSExporter object at ...>

        >>> IGSXMLFilesystemImporter(event)
        <Products.gsxml.content.XMLContentFSImporter object at ...>

        >>> IGSXMLFilesystemExporter(news)
        <Products.gsxml.content.XMLContentFSExporter object at ...>

        >>> IGSXMLFilesystemImporter(news)
        <Products.gsxml.content.XMLContentFSImporter object at ...>
    """

def test_suite():
    return unittest.TestSuite((
            ZopeDocTestSuite(test_class=GSXMLTestCase,
                             optionflags=optionflags),
        ))


# vim: set ts=4 sw=4 expandtab filetype=rst:
